# ObalaPalava

A Python SDK for **ObalaPalava**, a live translation system for **Pidgin → English**, from WAIT Technologies.

---

## Installation

```bash
pip install obalapalava



## Usage
```bash
from obalapalava import ObalaPalavaClient

client = ObalaPalavaClient()
print(client.translate("How far boss"))
